#!/bin/bash

# rsh-sw-update.sh - main SW updater script, located in /usr/local/bin
# Steps:
# 1) what is current version?
# 2) what is max version to upgrade to?
# 3) proceed through all UPG.{v#} directories and execute each version upgrade in order

SETTINGSDIR=/opt/settings
SYSDIR=${SETTINGSDIR}/sys
LOCALSRCDIR=/usr/local/src
UPGSRCDIR=${LOCALSRCDIR}/UPG
UPGVERFILE=${UPGSRCDIR}/ver
VERFILE=${SYSDIR}/ver
UPGVERFILETXT=${SYSDIR}/UPG-ver.txt

if [ ! -e $UPGSRCDIR ] ; then
	exit
fi

# ENV save
CURDIR=`pwd`

CURVER=`echo ${VERFILE}.* | grep -o ".$"`
UPGVERMAX=`echo ${UPGVERFILE}.* | grep -o ".$"`

if [ $CURVER -ge $UPGVERMAX ] ; then
	cd $CURDIR	# ENV reset	
	exit		# we're up-to-date, nothing to do
fi

NEXTVER=`expr $CURVER + 1`
for UPGver in `seq $NEXTVER 1 $UPGVERMAX` ; do
	cd ${UPGSRCDIR}
	DIRNAME=UPG.$UPGver
	cd $DIRNAME
	
	./rsh-upgrade.sh
	rm ${VERFILE}.*
	touch ${VERFILE}.$UPGver
	echo $UPGver >$UPGVERFILETXT
done

# ENV reset
cd $CURDIR