#!/bin/bash

# UPG.1 remote installer script
# get some info from the user
echo
echo "Raspberry Shake Upgrader - Ver0 to Ver1"
echo "More detailed output can be found in file 'rsh-upgrade.txt' in this same directory."
echo "You will need two pieces of information to complete this:"
echo "  1) The local ip of the raspberry shake unit to update, and"
echo "  2) The current password of the myshake user, you will enter this several times"
echo "Please hit the <ENTER> key when ready..."
read 

echo -n "Please enter the IP address of the r-shake to be updated:	"
read ipaddr

# variables
machcred=myshake@${ipaddr}
DLDIR=/opt/DL
UPGDIR=UPG.1
cmd=rsh-upgrade.sh
LOGF=rsh-upgrade.txt

# verify the IP address
echo -n "Verifying the IP Address..."
ping -q -c1 $ipaddr 1>/dev/null 2>&1
if [ "$?" != 0 ] ; then
	echo "	FAILURE"
	echo "IP Address $ipaddr does not respond to ping, unable to proceed"
	echo "Please verify connectivity and try again"
	echo "Quitting without doing anything, goodbye..."
	exit
else
	echo "	SUCCESS"
fi

# get the current version over there and verify it's at zero
echo "Verifying current version..."
VER=ver.0
VERFILE=/opt/settings/sys/$VER
echo -n "1/5:  "
scp ${machcred}:$VERFILE . 1>$LOGF 2>&1
if [ ! -e $VER ] ; then
	echo "Raspberry Shake Unit $ipaddr has already been updated, no need to update again"
	echo "Quitting without doing anything, goodbye..."
	exit
fi
echo "Version verified, issuing update commands..."

# copy over the installer and files
echo -n "2/5:  "
scp -r UPG.1 ${machcred}:$DLDIR 1>$LOGF 2>&1
code=$?
if [ $code -ne 0 ] ; then
	echo "File copy to the r-shake failed, cannot continue..."
	echo "Please check the IP address and password and try again."
	exit
fi

# execute installer
echo -n "3/5:  "
ssh $machcred ${DLDIR}/${UPGDIR}/$cmd 1>$LOGF 2>&1
code=$?
if [ $code -ne 0 ] ; then
	echo "File copy to the r-shake failed, cannot continue..."
	echo "Please check the IP address and password and try again."
	exit
fi

# cleanup
echo -n "4/5:  "
ssh $machcred "rm -r ${DLDIR}/${UPGDIR}" 1>$LOGF 2>&1

# reboot
echo "Issuing reboot command after next password entry, you may need to wait..."
echo -n "5/5:  "
ssh $machcred sudo reboot 1>$LOGF 2>&1

echo "Successfully Updated"
echo "Your Raspberry Shake is now rebooting..."
